==> ceph-rgw-2024.2.132+6b985e51b.tgz: ceph-rgw/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Uplift from Nautilus to Octopus release
- 0.1.3 update rbac api version
- 0.1.4 Rgw placement target support
- 0.1.5 Add tls support
- 0.1.6 Update tls override options
- 0.1.7 Use ca cert for helm tests
- 0.1.8 Add placement target delete support to RGW
- 0.1.9 Use full image ref for docker official images
- 0.1.10 Fix a bug in placement target deletion for new targets
- 0.1.11 Change s3 auth order to use local before external
- 0.1.12 Export crash dumps when Ceph daemons crash
- 0.1.13 Add configmap hash for keystone rgw
- 0.1.14 Disable crash dumps for rgw
- 0.1.15 Correct rgw placement target functions
- 0.1.16 Helm 3 - Fix Job labels
- 0.1.17 Update htk requirements
- 0.1.18 Consolidate mon_endpoints discovery
- 0.1.19 Add ClusterRole to the bootstrap-job
- 0.1.20 Enable taint toleration for Openstack services jobs
- 0.1.21 Correct mon discovery for multiple RGWs in different NS
- 0.1.22 Update default image values
- 0.1.23 Added OCI registry authentication
- 0.1.24 Replace civetweb with beast for unencrypted connections
- 0.1.25 Update all Ceph images to Focal
- 0.1.26 Replace node-role.kubernetes.io/master with control-plane
- 0.1.27 Update Ceph to 17.2.6
- 0.1.28 Use Helm toolkit functions for Ceph probes
- 0.1.29 Add 2023.1 Ubuntu Focal overrides
- 0.1.30 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.31 Add a ceph-rgw-pool job to manage RGW pools
- 0.1.32 Multiple namespace support for the ceph-rgw-pool job
- 0.1.33 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.34 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.35 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.36 Add 2024.1 Ubuntu Jammy overrides
- 0.1.37 Update heat image default tag to 2024.1-ubuntu_jammy
- 0.1.38 Add 2024.2 overrides
- 0.1.39 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> ceph-rgw-2025.1.3+35052e51b.tgz: ceph-rgw/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Uplift from Nautilus to Octopus release
- 0.1.3 update rbac api version
- 0.1.4 Rgw placement target support
- 0.1.5 Add tls support
- 0.1.6 Update tls override options
- 0.1.7 Use ca cert for helm tests
- 0.1.8 Add placement target delete support to RGW
- 0.1.9 Use full image ref for docker official images
- 0.1.10 Fix a bug in placement target deletion for new targets
- 0.1.11 Change s3 auth order to use local before external
- 0.1.12 Export crash dumps when Ceph daemons crash
- 0.1.13 Add configmap hash for keystone rgw
- 0.1.14 Disable crash dumps for rgw
- 0.1.15 Correct rgw placement target functions
- 0.1.16 Helm 3 - Fix Job labels
- 0.1.17 Update htk requirements
- 0.1.18 Consolidate mon_endpoints discovery
- 0.1.19 Add ClusterRole to the bootstrap-job
- 0.1.20 Enable taint toleration for Openstack services jobs
- 0.1.21 Correct mon discovery for multiple RGWs in different NS
- 0.1.22 Update default image values
- 0.1.23 Added OCI registry authentication
- 0.1.24 Replace civetweb with beast for unencrypted connections
- 0.1.25 Update all Ceph images to Focal
- 0.1.26 Replace node-role.kubernetes.io/master with control-plane
- 0.1.27 Update Ceph to 17.2.6
- 0.1.28 Use Helm toolkit functions for Ceph probes
- 0.1.29 Add 2023.1 Ubuntu Focal overrides
- 0.1.30 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.31 Add a ceph-rgw-pool job to manage RGW pools
- 0.1.32 Multiple namespace support for the ceph-rgw-pool job
- 0.1.33 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.34 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.35 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.36 Add 2024.1 Ubuntu Jammy overrides
- 0.1.37 Update heat image default tag to 2024.1-ubuntu_jammy
- 0.1.38 Add 2024.2 overrides
- 0.1.39 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
